@@ -76,7 +76,7 @@ fgetln(FILE *stream, size_t *len)
 	}
 }
 libbsd_link_warning(fgetln,
-                    "This functions cannot be safely ported, use getline(3) "
+                    "This function cannot be safely ported, use getline(3) "
                     "instead, as it is supported by GNU and POSIX.1-2008.")
 #else
 #error "Function fgetln() needs to be ported."
