@@ -30,6 +30,8 @@
 #include <stdio.h>
 #include <wchar.h>
 
+#include "local-link.h"
+
 struct filewbuf {
 	FILE *fp;
 	wchar_t *wbuf;
@@ -85,3 +87,6 @@ fgetwln(FILE *stream, size_t *lenp)
 	*lenp = wused;
 	return wused ? fb->wbuf : NULL;
 }
+libbsd_link_warning(fgetwln,
+                    "This function cannot be safely ported, use fgetwc(3) "
+                    "instead, as it is supported by C99 and POSIX.1-2001.")
